@@ -31,41 +31,41 @@ __all__ = ("DBInstanceAvailableWaiter", "DBInstanceDeletedWaiter")
 
 class DBInstanceAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstanceavailablewaiter)
     """
 
     def wait(
         self,
         *,
-        DBInstanceIdentifier: str = None,
-        Filters: Sequence["FilterTypeDef"] = None,
-        MaxRecords: int = None,
-        Marker: str = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        DBInstanceIdentifier: str = ...,
+        Filters: Sequence["FilterTypeDef"] = ...,
+        MaxRecords: int = ...,
+        Marker: str = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstanceavailablewaiter)
         """
 
 
 class DBInstanceDeletedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstancedeletedwaiter)
     """
 
     def wait(
         self,
         *,
-        DBInstanceIdentifier: str = None,
-        Filters: Sequence["FilterTypeDef"] = None,
-        MaxRecords: int = None,
-        Marker: str = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        DBInstanceIdentifier: str = ...,
+        Filters: Sequence["FilterTypeDef"] = ...,
+        MaxRecords: int = ...,
+        Marker: str = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters.html#dbinstancedeletedwaiter)
         """
